v0.3.1
=============
* Current version
* Add systematic module, with routine to simulate detector crosstalk.
* Fix bugs in the detector/SQUID labeling (instrument module).

v0.2.0
=============
* Add Fortran scripts and Makefile for the compilation.
* Add detector pointing and TOD modules.
* Doc contains end-to-end example (without systematic effect).
* Fix many bugs related to absolute imports (py 2 vs 3) and failed tests in doctest.

v0.1.0
=============
* First version of the repo (public)
* Add instrument and scanning strategy modules.
* Release public version.
